import React from 'react';
import { useAppSelector } from '../..';
import { selectProjects } from '../../data-access/store/projectSlice';

interface BreadcrumbProps {
  paths: string[];
  onNavigate: (index: number) => void;
}

export const Breadcrumb: React.FC<BreadcrumbProps> = ({ paths, onNavigate }) => {
  const projects = useAppSelector(selectProjects);

  const getProjectName = (projectId: string) => {
    return projects[projectId]?.name || projectId;
  };

  return (
    <div className="flex items-center space-x-2 text-sm">
      <button 
        onClick={() => onNavigate(-1)} 
        className="text-primary-600 hover:text-primary-800"
      >
        Home
      </button>
      {paths.map((path, index) => (
        <React.Fragment key={path}>
          <span className="text-secondary-400">/</span>
          <button
            onClick={() => onNavigate(index)}
            className="text-primary-600 hover:text-primary-800"
          >
            {getProjectName(path)}
          </button>
        </React.Fragment>
      ))}
    </div>
  );
};